| fm_set_call | R Documentation |
mids$callHelper Function for Setting mids$call
fm_set_call(mids, call)
mids |
A |
call |
A |
The mids object with an updated call (if call is not NULL).
Note that if call has arguments m, maxit, or seed, their values
are updated to reflect the corresponding attribute in mids.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.