| ibindlist | R Documentation |
mids ObjectsCombines a list of mids objects into a single mids
object. The resulting number of imputed data sets is equal to the sum of the
number of imputed data sets in each list element.
ibindlist(mids_list, call = NULL, seed = NULL, last_seed_value = NULL)
mids_list |
List of |
call |
An optional call to use for the |
seed |
An optional integer to set as the |
last_seed_value |
An optional |
The call, seed, and last_seed_value arguments are primarily used by
future_mice() and
future_mids(); they allow modification
of the mids object to match the equivalent
mice::mice() output exactly.
A combined mids object
# Create individual `mids` objects
mids1 <- mice::mice(mice::nhanes, m = 1L, maxit = 1L, seed = 1L)
mids2 <- mice::mice(mice::nhanes, m = 2L, maxit = 1L, seed = 2L)
mids3 <- mice::mice(mice::nhanes, m = 3L, maxit = 1L, seed = 3L)
# Combine imputations
mids6 <- ibindlist(list(mids1, mids2, mids3))
mids6
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.