| isplit | R Documentation |
mids Object into List of midsisplit() is the inverse of ibindlist()
and converts a single mids object into a list of mids objects containing
the largest number of chains possible while
distributing chains evenly among mids objects and
keeping the number of chains per object <= chunk_size.
The resulting number of objects is specified implicitly through mids$m and
chunk_size.
isplit(mids, chunk_size = 1L)
mids |
A |
chunk_size |
The number of to allocate to each smaller |
A list of mids objects
# Create `mids` object
mids <- mice::mice(mice::nhanes, m = 2L, maxit = 1L)
# Split into two - 1 imputation per object
mids_list <- isplit(mids)
mids_list
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.